function [ M ] = load_shape( filename )
%LOAD_SHAPE Loads the shape given in the file of 'filename'. 
%   Recognizes the trivert-tosca format (and soon others) and precalculates
%   the areas of each triangle and the lumped mass matrix. And the
%   triangle-wise differential, metric tensor and the mass center of each
%   triangle.

[pathstr, name, ext] = fileparts(filename);

if strcmp('.vert', ext)
   M = read_verttri(strcat(pathstr, name));
else
    error('load_shape: The file extension %s is not known.', ext);
end

% face areas

M.areas = tri_areas(M);

% (lumped) mass matrix

M.M = diag(vertex_voronoi(M));

% differential

M.Dx = trimesh_differential(M);

% metric tensor

M.g = trimesh_fff(M.Dx);

% mass center ?

M.center = 1/3 * (M.VERT(M.TRIV(:,1),:) + M.VERT(M.TRIV(:,2),:) + M.VERT(M.TRIV(:,3),:));

end

